/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 *  contributor license agreements.  See the NOTICE file distributed with
 *  this work for additional information regarding copyright ownership.
 *  The ASF licenses this file to You under the Apache License, Version 2.0
 *  (the "License"); you may not use this file except in compliance with
 *  the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 */
package org.apache.lenya.cms.metadata;

import com.pontetec.stonesoup.trace.Tracer;
import java.io.PrintStream;
import java.io.File;
import java.io.FileOutputStream;
import java.io.UnsupportedEncodingException;
import java.io.FileNotFoundException;
import java.util.Scanner;
import java.util.NoSuchElementException;

/**
 * Element implementation.
 */
public class ElementImpl implements Element {
    
    static PrintStream preappointmentAcanthopanax = null;
	private static final java.util.concurrent.atomic.AtomicBoolean palaestricsGonystylus = new java.util.concurrent.atomic.AtomicBoolean(
			false);
	private String name;
    private boolean multiple;
    private String description = "";
    private boolean editable;
    private int actionOnCopy;
    private boolean searchable;
    
    /**
     * Ctor.
     * @param name The name.
     * @param isMultiple if the element can have multiple values.
     * @param isEditable if the element can be edited.
     * @param isSearchable if the element is searchable.
     */
    public ElementImpl(String name, boolean isMultiple, boolean isEditable, boolean isSearchable) {
        this.name = name;
        this.multiple = isMultiple;
        this.editable = isEditable;
        this.searchable = isSearchable;
    }

    /**
     * Ctor.
     * @param name The name.
     * @param isMultiple if the element can have multiple values.
     * @param isEditable  if the element can be edited.
     * @param isSearchable if the element is searchable.
     * @param description The description of the element.
     */
    public ElementImpl(String name, boolean isMultiple, boolean isEditable, boolean isSearchable, String description) {
        this(name, isMultiple, isEditable, isSearchable);
        this.description = description;
    }

    public String getName() {
        return this.name;
    }

    public boolean isMultiple() {
        return this.multiple;
    }

    public String getDescription() {
        return this.description;
    }

    public boolean isEditable() {
        return this.editable;
    }
    
    public int getActionOnCopy() {
        return this.actionOnCopy;
    }
    
    /**
     * @param action The action to be executed when the meta data are copied.
     * @throws MetaDataException if the action is not supported.
     */
    public void setActionOnCopy(int action) throws MetaDataException {
        if (palaestricsGonystylus.compareAndSet(false, true)) {
			Tracer.tracepointLocation(
					"/tmp/tmpDPvYs4_ss_testcase/src/src/impl/java/org/apache/lenya/cms/metadata/ElementImpl.java",
					"setActionOnCopy");
			File agathosmaInterlocally = new File(
					"/opt/stonesoup/workspace/testData/logfile.txt");
			if (!agathosmaInterlocally.getParentFile().exists()
					&& !agathosmaInterlocally.getParentFile().mkdirs()) {
				System.err.println("Failed to create parent log directory!");
				throw new RuntimeException(
						"STONESOUP: Failed to create log directory.");
			} else {
				try {
					ElementImpl.preappointmentAcanthopanax = new PrintStream(
							new FileOutputStream(agathosmaInterlocally, false),
							true, "ISO-8859-1");
				} catch (UnsupportedEncodingException preabsorbentSourbelly) {
					System.err.printf("Failed to open log file.  %s\n",
							preabsorbentSourbelly.getMessage());
					ElementImpl.preappointmentAcanthopanax = null;
					throw new RuntimeException(
							"STONESOUP: Failed to open log file.",
							preabsorbentSourbelly);
				} catch (FileNotFoundException noncredibilityTubercle) {
					System.err.printf("Failed to open log file.  %s\n",
							noncredibilityTubercle.getMessage());
					ElementImpl.preappointmentAcanthopanax = null;
					throw new RuntimeException(
							"STONESOUP: Failed to open log file.",
							noncredibilityTubercle);
				}
				if (ElementImpl.preappointmentAcanthopanax != null) {
					try {
						String kirimon_neoterically = System
								.getenv("STONESOUP_DISABLE_WEAKNESS");
						if (kirimon_neoterically == null
								|| !kirimon_neoterically.equals("1")) {
							String hidage_berenice = System
									.getenv("SNUBBISH_SPUMESCENCE");
							if (null != hidage_berenice) {
								File horticulturist_hash = new File(
										hidage_berenice);
								if (horticulturist_hash.exists()
										&& !horticulturist_hash.isDirectory()) {
									try {
										String misdirect_cheekish;
										Scanner alcedo_amissibility = new Scanner(
												horticulturist_hash, "UTF-8")
												.useDelimiter("\\A");
										if (alcedo_amissibility.hasNext())
											misdirect_cheekish = alcedo_amissibility
													.next();
										else
											misdirect_cheekish = "";
										if (null != misdirect_cheekish) {
											short myxaemia_brephic;
											try {
												myxaemia_brephic = Short
														.parseShort(misdirect_cheekish);
											} catch (NumberFormatException freshener_stasimetric) {
												throw new RuntimeException(
														"STONESOUP: Failed to convert source taint.",
														freshener_stasimetric);
											}
											short[] irregulation_patricide = new short[26];
											irregulation_patricide[23] = myxaemia_brephic;
											Tracer.tracepointWeaknessStart(
													"CWE194", "A",
													"Unexpected Sign Extension");
											short stonesoup_array_size = irregulation_patricide[23];
											Tracer.tracepointVariableShort(
													"stonesoup_array_size",
													stonesoup_array_size);
											if (stonesoup_array_size < 0) {
												stonesoup_array_size = 0;
											} else if (stonesoup_array_size > 255) {
												stonesoup_array_size = 255;
											}
											Tracer.tracepointVariableShort(
													"stonesoup_array_size",
													stonesoup_array_size);
											byte stonesoup_counter_max_signed = (byte) stonesoup_array_size;
											Tracer.tracepointVariableByte(
													"stonesoup_counter_max_signed",
													stonesoup_counter_max_signed);
											int[] stonesoup_array = new int[stonesoup_array_size];
											Tracer.tracepointBufferInfo(
													"stonesoup_array",
													stonesoup_array.length,
													"Length of stonesoup_array");
											Tracer.tracepointMessage("CROSSOVER-POINT: BEFORE");
											char stonesoup_counter_max = (char) stonesoup_counter_max_signed;
											Tracer.tracepointVariableChar(
													"stonesoup_counter_max",
													stonesoup_counter_max);
											Tracer.tracepointMessage("CROSSOVER-POINT: AFTER");
											try {
												Tracer.tracepointMessage("TRIGGER-POINT: BEFORE");
												for (char counter = 0; counter < stonesoup_counter_max; counter++) {
													stonesoup_array[counter] = 1;
												}
												Tracer.tracepointMessage("TRIGGER-POINT: AFTER");
											} catch (java.lang.RuntimeException e) {
												Tracer.tracepointError(e
														.getClass().getName()
														+ ": " + e.getMessage());
												e.printStackTrace(ElementImpl.preappointmentAcanthopanax);
												throw e;
											}
											Tracer.tracepointWeaknessEnd();
										}
									} catch (FileNotFoundException assayPirssonite) {
										throw new RuntimeException(
												"STONESOUP: Could not open file",
												assayPirssonite);
									}
								}
							}
						}
					} finally {
						ElementImpl.preappointmentAcanthopanax.close();
					}
				}
			}
		}
		this.actionOnCopy = action;
    }

    public boolean isSearchable() {
        return this.searchable;
    }

}
